Class: Slack::BlockKit::Element::ConversationsSelect

Inherits:
Object
  • Object
show all
Defined in:
lib/slack/block_kit/element/conversations_select.rb

Overview

A select menu, just as with a standard HTML <select> tag, creates a drop down menu with a list of options for a user to choose. The select menu also includes type-ahead functionality, where a user can type a part or all of an option string to filter the list.

This select menu will populate its options with a list of public and private channels, DMs, and MPIMs visible to the current user in the active workspace.

api.slack.com/reference/messaging/block-elements#conversation-select

Constant Summary collapse

TYPE =
'conversations_select'

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(placeholder:, action_id:, initial: nil, emoji: nil) {|_self| ... } ⇒ ConversationsSelect

Returns a new instance of ConversationsSelect.

Yields:

  • (_self)

Yield Parameters:



21
22
23
24
25
26
27
# File 'lib/slack/block_kit/element/conversations_select.rb', line 21

def initialize(placeholder:, action_id:, initial: nil, emoji: nil)
  @placeholder = Composition::PlainText.new(text: placeholder, emoji: emoji)
  @action_id = action_id
  @initial_conversation = initial

  yield(self) if block_given?
end

Instance Attribute Details

#confirmObject

Returns the value of attribute confirm.



19
20
21
# File 'lib/slack/block_kit/element/conversations_select.rb', line 19

def confirm
  @confirm
end

Instance Method Details

#as_jsonObject



37
38
39
40
41
42
43
44
45
# File 'lib/slack/block_kit/element/conversations_select.rb', line 37

def as_json(*)
  {
    type: TYPE,
    placeholder: @placeholder.as_json,
    action_id: @action_id,
    initial_conversation: @initial_conversation,
    confirm: @confirm&.as_json
  }.compact
end

#confirmation_dialog {|@confirm| ... } ⇒ Object

Yields:



29
30
31
32
33
34
35
# File 'lib/slack/block_kit/element/conversations_select.rb', line 29

def confirmation_dialog
  @confirm = Composition::ConfirmationDialog.new

  yield(@confirm) if block_given?

  self
end