Class: Slack::BlockKit::Element::MultiConversationsSelect

Inherits:
Object
  • Object
show all
Defined in:
lib/slack/block_kit/element/multi_conversations_select.rb

Overview

A select menu, just as with a standard HTML <select> tag, creates a drop down menu with a list of options for a user to choose. The select menu also includes type-ahead functionality, where a user can type a part or all of an option string to filter the list.

This multi-select menu will populate its options with a list of public and private channels, DMs, and MPIMs visible to the current user in the active workspace.

api.slack.com/reference/block-kit/block-elements#conversation_multi_select

Constant Summary collapse

TYPE =
'multi_conversations_select'

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(placeholder:, action_id:, initial: nil, emoji: nil, max_selected_items: nil) {|_self| ... } ⇒ MultiConversationsSelect

Returns a new instance of MultiConversationsSelect.

Yields:

  • (_self)

Yield Parameters:



21
22
23
24
25
26
27
28
29
30
# File 'lib/slack/block_kit/element/multi_conversations_select.rb', line 21

def initialize(placeholder:, action_id:, initial: nil, emoji: nil, max_selected_items: nil)
  @placeholder = Composition::PlainText.new(text: placeholder, emoji: emoji)
  @action_id = action_id
  @initial_conversation = initial
  @confirm = nil
  @max_selected_items = max_selected_items
  @filter = nil

  yield(self) if block_given?
end

Instance Attribute Details

#confirmObject

Returns the value of attribute confirm.



19
20
21
# File 'lib/slack/block_kit/element/multi_conversations_select.rb', line 19

def confirm
  @confirm
end

Instance Method Details

#as_jsonObject



52
53
54
55
56
57
58
59
60
61
62
# File 'lib/slack/block_kit/element/multi_conversations_select.rb', line 52

def as_json(*)
  {
    type: TYPE,
    placeholder: @placeholder.as_json,
    action_id: @action_id,
    initial_conversation: @initial_conversation,
    confirm: @confirm&.as_json,
    max_selected_items: @max_selected_items,
    filter: @filter&.as_json
  }.compact
end

#confirmation_dialog {|@confirm| ... } ⇒ Object

Yields:



32
33
34
35
36
37
38
# File 'lib/slack/block_kit/element/multi_conversations_select.rb', line 32

def confirmation_dialog
  @confirm = Composition::ConfirmationDialog.new

  yield(@confirm) if block_given?

  self
end

#filter(only: nil, exclude_external_shared_channels: nil, exclude_bot_users: nil) ⇒ Object



40
41
42
43
44
45
46
47
48
49
50
# File 'lib/slack/block_kit/element/multi_conversations_select.rb', line 40

def filter(only: nil,
           exclude_external_shared_channels: nil,
           exclude_bot_users: nil)
  @filter = Composition::ConversationFilter.new(
    only: only,
    exclude_external_shared_channels: exclude_external_shared_channels,
    exclude_bot_users: exclude_bot_users
  )

  self
end