Class: Slack::BlockKit::Element::MultiExternalSelect
- Inherits:
-
Object
- Object
- Slack::BlockKit::Element::MultiExternalSelect
- Defined in:
- lib/slack/block_kit/element/multi_external_select.rb
Overview
A select menu, just as with a standard HTML <select> tag, creates a drop down menu with a list of options for a user to choose. The select menu also includes type-ahead functionality, where a user can type a part or all of an option string to filter the list.
This select menu will load its options from an external data source, allowing for a dynamic list of options.
Each time a select menu of this type is opened or the user starts typing in the typeahead field, we’ll send a request to your specified URL. Your app should return an HTTP 200 OK response, along with an application/json post body with an object containing either an options array, or an option_groups array.
api.slack.com/reference/block-kit/block-elements#external_multi_select
Constant Summary collapse
- TYPE =
'multi_external_select'
Instance Method Summary collapse
- #as_json ⇒ Object
-
#initialize(placeholder:, action_id:, initial: nil, min_query_length: nil, emoji: nil, max_selected_items: nil) {|_self| ... } ⇒ MultiExternalSelect
constructor
A new instance of MultiExternalSelect.
Methods included from Composition::ConfirmationDialog::Confirmable
#confirmation_dialog, included
Constructor Details
#initialize(placeholder:, action_id:, initial: nil, min_query_length: nil, emoji: nil, max_selected_items: nil) {|_self| ... } ⇒ MultiExternalSelect
Returns a new instance of MultiExternalSelect.
26 27 28 29 30 31 32 33 34 35 36 |
# File 'lib/slack/block_kit/element/multi_external_select.rb', line 26 def initialize(placeholder:, action_id:, initial: nil, min_query_length: nil, emoji: nil, max_selected_items: nil) @placeholder = Composition::PlainText.new(text: placeholder, emoji: emoji) @action_id = action_id = initial @min_query_length = min_query_length @max_selected_items = max_selected_items yield(self) if block_given? end |
Instance Method Details
#as_json ⇒ Object
38 39 40 41 42 43 44 45 46 47 48 |
# File 'lib/slack/block_kit/element/multi_external_select.rb', line 38 def as_json(*) { type: TYPE, placeholder: @placeholder.as_json, action_id: @action_id, initial_options: &.map(&:as_json), min_query_length: @min_query_length, confirm: confirm&.as_json, max_selected_items: @max_selected_items }.compact end |