Class: Slack::BlockKit::Element::MultiStaticSelect

Inherits:
Object
  • Object
show all
Includes:
Composition::ConfirmationDialog::Confirmable
Defined in:
lib/slack/block_kit/element/multi_static_select.rb

Overview

A select menu, just as with a standard HTML <select> tag, creates a drop down menu with a list of options for a user to choose. The select menu also includes type-ahead functionality, where a user can type a part or all of an option string to filter the list.

This is the simplest form of select menu, with a static list of options passed in when defining the element.

api.slack.com/reference/block-kit/block-elements#static_multi_select

Constant Summary collapse

TYPE =
'multi_static_select'

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods included from Composition::ConfirmationDialog::Confirmable

#confirmation_dialog, included

Constructor Details

#initialize(placeholder:, action_id:, emoji: nil, max_selected_items: nil) {|_self| ... } ⇒ MultiStaticSelect

Returns a new instance of MultiStaticSelect.

Yields:

  • (_self)

Yield Parameters:



22
23
24
25
26
27
28
29
30
31
# File 'lib/slack/block_kit/element/multi_static_select.rb', line 22

def initialize(placeholder:, action_id:, emoji: nil, max_selected_items: nil)
  @placeholder = Composition::PlainText.new(text: placeholder, emoji: emoji)
  @action_id = action_id
  @max_selected_items = max_selected_items

  @options = nil
  @option_groups = nil

  yield(self) if block_given?
end

Instance Attribute Details

#option_groupsObject

Returns the value of attribute option_groups.



20
21
22
# File 'lib/slack/block_kit/element/multi_static_select.rb', line 20

def option_groups
  @option_groups
end

#optionsObject

Returns the value of attribute options.



20
21
22
# File 'lib/slack/block_kit/element/multi_static_select.rb', line 20

def options
  @options
end

Instance Method Details

#as_jsonObject



56
57
58
59
60
61
62
63
64
65
66
67
# File 'lib/slack/block_kit/element/multi_static_select.rb', line 56

def as_json(*)
  {
    type: TYPE,
    placeholder: @placeholder.as_json,
    action_id: @action_id,
    options: @options&.map(&:as_json),
    option_groups: @option_groups&.map(&:as_json),
    initial_options: initial_options&.map(&:as_json),
    confirm: confirm&.as_json,
    max_selected_items: @max_selected_items
  }.compact
end

#option(value:, text:, initial: false, emoji: nil) ⇒ Object



33
34
35
36
37
38
39
40
41
42
43
# File 'lib/slack/block_kit/element/multi_static_select.rb', line 33

def option(value:, text:, initial: false, emoji: nil)
  @options ||= []
  @options << Composition::Option.new(
    value: value,
    text: text,
    emoji: emoji,
    initial: initial
  )

  self
end

#option_group(label:, emoji: nil) {|option_group| ... } ⇒ Object

Yields:



45
46
47
48
49
50
51
52
53
54
# File 'lib/slack/block_kit/element/multi_static_select.rb', line 45

def option_group(label:, emoji: nil)
  option_group = Composition::OptionGroup.new(label: label, emoji: emoji)

  yield(option_group) if block_given?

  @option_groups ||= []
  @option_groups << option_group

  self
end