Class: Slack::BlockKit::Element::MultiUsersSelect
- Inherits:
-
Object
- Object
- Slack::BlockKit::Element::MultiUsersSelect
- Defined in:
- lib/slack/block_kit/element/multi_users_select.rb
Overview
A select menu, just as with a standard HTML <select> tag, creates a drop down menu with a list of options for a user to choose. The select menu also includes type-ahead functionality, where a user can type a part or all of an option string to filter the list.
This multi-select menu will populate its options with a list of Slack users visible to the current user in the active workspace.
api.slack.com/reference/block-kit/block-elements#users_multi_select
Constant Summary collapse
- TYPE =
'multi_users_select'
Instance Attribute Summary collapse
-
#confirm ⇒ Object
Returns the value of attribute confirm.
Instance Method Summary collapse
- #as_json ⇒ Object
- #confirmation_dialog {|@confirm| ... } ⇒ Object
-
#initialize(placeholder:, action_id:, initial: nil, emoji: nil, max_selected_items: nil) {|_self| ... } ⇒ MultiUsersSelect
constructor
A new instance of MultiUsersSelect.
Constructor Details
#initialize(placeholder:, action_id:, initial: nil, emoji: nil, max_selected_items: nil) {|_self| ... } ⇒ MultiUsersSelect
Returns a new instance of MultiUsersSelect.
20 21 22 23 24 25 26 27 28 |
# File 'lib/slack/block_kit/element/multi_users_select.rb', line 20 def initialize(placeholder:, action_id:, initial: nil, emoji: nil, max_selected_items: nil) @placeholder = Composition::PlainText.new(text: placeholder, emoji: emoji) @action_id = action_id @initial_user = initial @confirm = nil @max_selected_items = max_selected_items yield(self) if block_given? end |
Instance Attribute Details
#confirm ⇒ Object
Returns the value of attribute confirm.
18 19 20 |
# File 'lib/slack/block_kit/element/multi_users_select.rb', line 18 def confirm @confirm end |
Instance Method Details
#as_json ⇒ Object
38 39 40 41 42 43 44 45 46 47 |
# File 'lib/slack/block_kit/element/multi_users_select.rb', line 38 def as_json(*) { type: TYPE, placeholder: @placeholder.as_json, action_id: @action_id, initial_user: @initial_user, confirm: @confirm&.as_json, max_selected_items: @max_selected_items }.compact end |
#confirmation_dialog {|@confirm| ... } ⇒ Object
30 31 32 33 34 35 36 |
# File 'lib/slack/block_kit/element/multi_users_select.rb', line 30 def confirmation_dialog @confirm = Composition::ConfirmationDialog.new yield(@confirm) if block_given? self end |