Class: Slack::BlockKit::Element::MultiExternalSelect
- Inherits:
-
Object
- Object
- Slack::BlockKit::Element::MultiExternalSelect
- Defined in:
- lib/slack/block_kit/element/multi_external_select.rb
Overview
A select menu, just as with a standard HTML <select> tag, creates a drop down menu with a list of options for a user to choose. The select menu also includes type-ahead functionality, where a user can type a part or all of an option string to filter the list.
This select menu will load its options from an external data source, allowing for a dynamic list of options.
Each time a select menu of this type is opened or the user starts typing in the typeahead field, we’ll send a request to your specified URL. Your app should return an HTTP 200 OK response, along with an application/json post body with an object containing either an options array, or an option_groups array.
api.slack.com/reference/block-kit/block-elements#external_multi_select
Constant Summary collapse
- TYPE =
'multi_external_select'
Instance Attribute Summary collapse
-
#confirm ⇒ Object
Returns the value of attribute confirm.
Instance Method Summary collapse
- #as_json ⇒ Object
- #confirmation_dialog {|@confirm| ... } ⇒ Object
-
#initialize(placeholder:, action_id:, initial: nil, min_query_length: nil, emoji: nil, max_selected_items: nil) {|_self| ... } ⇒ MultiExternalSelect
constructor
A new instance of MultiExternalSelect.
Constructor Details
#initialize(placeholder:, action_id:, initial: nil, min_query_length: nil, emoji: nil, max_selected_items: nil) {|_self| ... } ⇒ MultiExternalSelect
Returns a new instance of MultiExternalSelect.
26 27 28 29 30 31 32 33 34 35 36 37 |
# File 'lib/slack/block_kit/element/multi_external_select.rb', line 26 def initialize(placeholder:, action_id:, initial: nil, min_query_length: nil, emoji: nil, max_selected_items: nil) @placeholder = Composition::PlainText.new(text: placeholder, emoji: emoji) @action_id = action_id @initial_option = initial @min_query_length = min_query_length @confirm = nil @max_selected_items = max_selected_items yield(self) if block_given? end |
Instance Attribute Details
#confirm ⇒ Object
Returns the value of attribute confirm.
24 25 26 |
# File 'lib/slack/block_kit/element/multi_external_select.rb', line 24 def confirm @confirm end |
Instance Method Details
#as_json ⇒ Object
47 48 49 50 51 52 53 54 55 56 57 |
# File 'lib/slack/block_kit/element/multi_external_select.rb', line 47 def as_json(*) { type: TYPE, placeholder: @placeholder.as_json, action_id: @action_id, initial_option: @initial_option&.as_json, min_query_length: @min_query_length, confirm: @confirm&.as_json, max_selected_items: @max_selected_items }.compact end |
#confirmation_dialog {|@confirm| ... } ⇒ Object
39 40 41 42 43 44 45 |
# File 'lib/slack/block_kit/element/multi_external_select.rb', line 39 def confirmation_dialog @confirm = Composition::ConfirmationDialog.new yield(@confirm) if block_given? self end |