Class: Slack::BlockKit::Element::MultiStaticSelect

Inherits:
Object
  • Object
show all
Defined in:
lib/slack/block_kit/element/multi_static_select.rb

Overview

A select menu, just as with a standard HTML <select> tag, creates a drop down menu with a list of options for a user to choose. The select menu also includes type-ahead functionality, where a user can type a part or all of an option string to filter the list.

This is the simplest form of select menu, with a static list of options passed in when defining the element.

api.slack.com/reference/block-kit/block-elements#static_multi_select

Constant Summary collapse

TYPE =
'multi_static_select'

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(placeholder:, action_id:, emoji: nil, max_selected_items: nil) {|_self| ... } ⇒ MultiStaticSelect

Returns a new instance of MultiStaticSelect.

Yields:

  • (_self)

Yield Parameters:



20
21
22
23
24
25
26
27
28
29
30
31
# File 'lib/slack/block_kit/element/multi_static_select.rb', line 20

def initialize(placeholder:, action_id:, emoji: nil, max_selected_items: nil)
  @placeholder = Composition::PlainText.new(text: placeholder, emoji: emoji)
  @action_id = action_id
  @confirm = nil
  @max_selected_items = max_selected_items

  @options = nil
  @option_groups = nil
  @initial_option = nil

  yield(self) if block_given?
end

Instance Attribute Details

#confirmObject

Returns the value of attribute confirm.



18
19
20
# File 'lib/slack/block_kit/element/multi_static_select.rb', line 18

def confirm
  @confirm
end

#initial_optionObject

Returns the value of attribute initial_option.



18
19
20
# File 'lib/slack/block_kit/element/multi_static_select.rb', line 18

def initial_option
  @initial_option
end

#option_groupsObject

Returns the value of attribute option_groups.



18
19
20
# File 'lib/slack/block_kit/element/multi_static_select.rb', line 18

def option_groups
  @option_groups
end

#optionsObject

Returns the value of attribute options.



18
19
20
# File 'lib/slack/block_kit/element/multi_static_select.rb', line 18

def options
  @options
end

Instance Method Details

#as_jsonObject



73
74
75
76
77
78
79
80
81
82
83
84
# File 'lib/slack/block_kit/element/multi_static_select.rb', line 73

def as_json(*)
  {
    type: TYPE,
    placeholder: @placeholder.as_json,
    action_id: @action_id,
    options: @options&.map(&:as_json),
    option_groups: @option_groups&.map(&:as_json),
    initial_option: @initial_option&.as_json,
    confirm: @confirm&.as_json,
    max_selected_items: @max_selected_items
  }.compact
end

#confirmation_dialog {|@confirm| ... } ⇒ Object

Yields:



33
34
35
36
37
38
39
# File 'lib/slack/block_kit/element/multi_static_select.rb', line 33

def confirmation_dialog
  @confirm = Composition::ConfirmationDialog.new

  yield(@confirm) if block_given?

  self
end

#initial(value:, text:, emoji: nil) ⇒ Object



63
64
65
66
67
68
69
70
71
# File 'lib/slack/block_kit/element/multi_static_select.rb', line 63

def initial(value:, text:, emoji: nil)
  @initial_option = Composition::Option.new(
    value: value,
    text: text,
    emoji: emoji
  )

  self
end

#option(value:, text:, emoji: nil) ⇒ Object



41
42
43
44
45
46
47
48
49
50
# File 'lib/slack/block_kit/element/multi_static_select.rb', line 41

def option(value:, text:, emoji: nil)
  @options ||= []
  @options << Composition::Option.new(
    value: value,
    text: text,
    emoji: emoji
  )

  self
end

#option_group(label:, emoji: nil) {|option_group| ... } ⇒ Object

Yields:



52
53
54
55
56
57
58
59
60
61
# File 'lib/slack/block_kit/element/multi_static_select.rb', line 52

def option_group(label:, emoji: nil)
  option_group = Composition::OptionGroup.new(label: label, emoji: emoji)

  yield(option_group) if block_given?

  @option_groups ||= []
  @option_groups << option_group

  self
end